@@ -104,6 +104,10 @@ MEDIA_ROOT = os.path.join(PROJECT_PATH, 'media/')
 # trailing slash.
 MEDIA_URL = '/media/'
 
+# The maximum size of user uploaded images in bytes. If you use NGINX, note
+# that also it needs to support at least this size.
+MEDIA_MAX_SIZE = False
+
 # Absolute path to the directory static files should be collected to.
 # Don't put anything in this directory yourself; store your static files
 # in apps' "static/" subdirectories and in STATICFILES_DIRS.
@@ -192,6 +196,7 @@ BASE_INSTALLED_APPS = [
     'django.contrib.admindocs',
     'django.contrib.flatpages',
     'django_js_error_hook',
+    'loginas',
     'fixturemedia',
     'browser_check',
     'menu',
@@ -206,6 +211,7 @@ BASE_INSTALLED_APPS = [
     'feedback',
     'style'
 ]
+
 # These are additional apps to be overriden by configuration.py
 INSTALLED_APPS = []
 
@@ -239,9 +245,16 @@ LANGUAGES = (
     ('pt-br', gettext('Portuguese (Brazil)')),
 )
 
-
 LOGIN_REDIRECT_URL = '/'
 
+
+# Allow users with login_as permission to log in as different user
+def can_login_as(request, target_user):
+    return request.user.has_perm('user.can_login_as')
+
+
+CAN_LOGIN_AS = can_login_as
+
 ACCOUNT_EMAIL_REQUIRED = True
 ACCOUNT_EMAIL_VERIFICATION = "mandatory"
 
