@@ -5,7 +5,7 @@ import {litToText, nameToText} from "../tools"
 import {editCategoriesTemplate} from "./templates"
 import {BibTypeTitles} from "../form/strings"
 import {SiteMenu} from "../../menu"
-import {OverviewMenuView, findTarget, whenReady, Dialog, baseBodyTemplate, ensureCSS, setDocTitle, escapeText, DatatableBulk} from "../../common"
+import {OverviewMenuView, findTarget, whenReady, Dialog, baseBodyTemplate, ensureCSS, setDocTitle, escapeText, DatatableBulk, addAlert} from "../../common"
 import {FeedbackTab} from "../../feedback"
 import {menuModel, bulkMenuModel} from "./menu"
 import * as plugins from "../../../plugins/bibliography_overview"
@@ -21,9 +21,9 @@ export class BibliographyOverview {
      * @function bind
      */
     init() {
-        whenReady().then(() => {
+        return whenReady().then(() => {
             this.render()
-            const smenu = new SiteMenu("bibliography")
+            const smenu = new SiteMenu(this.app, "bibliography")
             smenu.init()
             this.menu = new OverviewMenuView(this, menuModel)
             this.menu.init()
@@ -154,7 +154,7 @@ export class BibliographyOverview {
     createTableRow(id) {
         const bibInfo = this.app.bibDB.db[id]
         const bibauthors = bibInfo.fields.author || bibInfo.fields.editor
-        const cats = bibInfo.entry_cat.map(cat => `cat_${cat}`)
+        const cats = bibInfo.cats.map(cat => `cat_${cat}`)
         return [
             String(id),
             `<input type="checkbox" class="entry-select fw-check" data-id="${id}" id="bib-${id}"><label for="bib-${id}"></label>`, // checkbox
@@ -190,12 +190,16 @@ export class BibliographyOverview {
      * @function editCategoriesDialog
      */
     editCategoriesDialog() {
+        if (this.app.isOffline()) {
+            addAlert('info', gettext('You are currently offline. Please try again when you are back online.'))
+            return
+        }
         const buttons = [
             {
                 text: gettext('Submit'),
                 classes: "fw-dark",
                 click: () => {
-                    const cats = {ids:[], titles:[]}
+                    const cats = {ids: [], titles: []}
                     this.dom.querySelectorAll('#editCategories .category-form').forEach(
                         el => {
                             const title = el.value.trim()
@@ -205,7 +209,11 @@ export class BibliographyOverview {
                             }
                         }
                     )
-                    this.saveCategories(cats)
+                    if (this.app.isOffline()) {
+                        addAlert('info', gettext('You are currently offline. Please try again when you are back online.'))
+                    } else {
+                        this.saveCategories(cats)
+                    }
                     dialog.close()
                 }
             },
@@ -291,7 +299,7 @@ export class BibliographyOverview {
             case findTarget(event, '.edit-bib', el): {
                 const bookId = parseInt(el.target.dataset.id)
                 import("../form").then(({BibEntryForm}) => {
-                    const form = new BibEntryForm(this.app.bibDB, bookId)
+                    const form = new BibEntryForm(this.app.bibDB, this.app, bookId)
                     form.init().then(
                         idTranslations => {
                             const ids = idTranslations.map(idTrans => idTrans[1])
