@@ -7,7 +7,7 @@ import {
     ImageSelectionDialog
 } from "../../images/selection_dialog"
 import {
-    addDropdownBox,
+    dropdownSelect,
     Dialog,
     ContentMenu
 } from "../../common"
@@ -26,12 +26,12 @@ export class FigureDialog {
         this.insideFigure = false
         this.figureNode = false
         this.contentNode = false
-        this.caption = ''
-        this.figureCategory = 'none'
+        this.caption = true
+        this.category = 'none'
         this.aligned = 'center'
         this.width = "50"
         this.equation = ''
-        this.node = this.editor.currentView.state.selection.node
+        this.node = false
         this.submitMessage = gettext('Insert')
         this.dialog = false
     }
@@ -70,11 +70,11 @@ export class FigureDialog {
                     }
                 },
                 onContentDidChange: () => {
-                    this.equation = this.mathField.$latex()
+                    this.equation = this.mathField.getValue()
                     this.showHideNonMathElements()
                 }
             })
-            this.mathField.$latex(this.equation)
+            this.mathField.setValue(this.equation)
             this.showPlaceHolder()
             this.showHideNonMathElements()
             this.dialog.dialogEl.querySelector('#insert-figure-image').addEventListener(
@@ -86,7 +86,7 @@ export class FigureDialog {
     }
 
     showPlaceHolder() {
-        if (!this.mathField.$latex().length) {
+        if (!this.mathField.getValue().length) {
             this.mathliveDOM.insertAdjacentHTML('beforeend', `<span class="placeholder" >${gettext('Type formula')}</span>`)
         }
     }
@@ -139,7 +139,6 @@ export class FigureDialog {
     layoutImagePreview() {
         if (this.imgId) {
             if (this.mathField) {
-                this.mathField.$revertToOriginalContent()
                 this.mathField = false
             }
             const db = this.imgDb === 'document' ? this.imageDB.db : this.userImageDB.db
@@ -163,25 +162,7 @@ export class FigureDialog {
         }
     }
 
-    setFigureLabel() {
-        this.dialog.dialogEl.querySelector('#figure-category-btn .label').innerHTML =
-            document.getElementById(`figure-category-${this.figureCategory}`).innerText
-    }
-
-    setFigureAlignment() {
-        this.dialog.dialogEl.querySelector('#figure-alignment-btn .label').innerHTML =
-            document.getElementById(`figure-alignment-${this.aligned}`).innerText
-    }
-
-    setFigureWidth() {
-        this.dialog.dialogEl.querySelector('#figure-width-btn .label').innerHTML =
-            document.getElementById(`figure-width-${this.width}`).innerText
-
-    }
-
     submitForm() {
-        const captionInput = this.dialog.dialogEl.querySelector('input[name=figure-caption]')
-        this.caption = captionInput.value
 
         if ((new RegExp(/^\s*$/)).test(this.equation) && (!this.imgId)) {
             // The math input is empty. Delete a math node if it exist. Then close the dialog.
@@ -199,19 +180,20 @@ export class FigureDialog {
             imageEntry.copyright = this.copyright
             this.imageDB.setImage(this.imgId, imageEntry)
             this.imgDb = 'document'
-        } else if (this.imgId && !deepEqual(this.copyright, this.imageDB.db[this.imgId].copyright)) {
+        } else if (this.imgId && this.imageDB.db[this.imgId] && !deepEqual(this.copyright, this.imageDB.db[this.imgId].copyright)) {
             const imageEntry = JSON.parse(JSON.stringify(this.imageDB.db[this.imgId]))
             imageEntry.copyright = this.copyright
             this.imageDB.setImage(this.imgId, imageEntry)
         }
 
+
         if (
             this.insideFigure &&
-            this.equation === this.node.attrs.equation &&
-            (this.imgId === this.node.attrs.image) &&
+            this.equation === (this.node.content.content.find(node => node.type.name === 'figure_equation')?.attrs.equation || '') &&
+            this.imgId === (this.node.content.content.find(node => node.type.name === 'image')?.attrs.image || false) &&
             this.imgDb === 'document' &&
             this.caption === this.node.attrs.caption &&
-            this.figureCategory === this.node.attrs.figureCategory &&
+            this.category === this.node.attrs.category &&
             this.aligned === this.node.attrs.aligned &&
             this.width === this.node.attrs.width
         ) {
@@ -219,36 +201,70 @@ export class FigureDialog {
             this.dialog.close()
             return false
         }
-
-        // This is the node wherein figureAlignment will affect the attribute
-        const nodeType = this.editor.currentView.state.schema.nodes['figure']
+        const content = []
+        if (this.imgId) {
+            content.push(
+                this.editor.currentView.state.schema.nodes['image'].create({image: this.imgId})
+            )
+        } else {
+            content.push(
+                this.editor.currentView.state.schema.nodes['figure_equation'].create({equation: this.equation})
+            )
+        }
+        const captionNode = this.node.content?.content.find(node => node.type.name === 'figure_caption') ||
+            this.editor.currentView.state.schema.nodes['figure_caption'].create()
+        if (this.category === 'table') {
+            content.unshift(captionNode)
+        } else {
+            content.push(captionNode)
+        }
         const tr = this.editor.currentView.state.tr.replaceSelectionWith(
-            nodeType.createAndFill({
-                equation: this.equation,
-                image: this.imgId,
-                aligned: this.aligned,
-                width: this.width,
-                figureCategory: this.figureCategory,
-                caption: this.caption,
-                id: this.insideFigure ? this.node.attrs.id : randomFigureId()
-            })
+            this.editor.currentView.state.schema.nodes['figure'].createAndFill(
+                {
+                    aligned: this.aligned,
+                    width: this.width,
+                    category: this.category,
+                    caption: this.caption,
+                    id: this.insideFigure ? this.node.attrs.id : randomFigureId()
+                },
+                content
+            )
         )
         this.editor.currentView.dispatch(tr)
 
         this.dialog.close()
     }
 
+    findFigure(state) {
+        if (state.selection.node && state.selection.node.type.name == "figure") {
+            return state.selection.node
+        }
+        const $head = state.selection.$head
+        for (let d = $head.depth; d > 0; d--) {
+            if ($head.node(d).type.name == "figure") {
+                return $head.node(d)
+            }
+        }
+        return false
+    }
+
     init() {
-        // toolbar figure
+        this.node = this.findFigure(this.editor.currentView.state)
+
+        if (this.node?.attrs?.track?.find(track => track.type === 'deletion')) {
+            // The figure is marked as deleted so we don't allow editing it.
+            return true
+        }
+
         const buttons = []
 
-        if (this.node && this.node.type && this.node.type.name === 'figure') {
+        if (this.node?.type && this.node?.type.name === 'figure') {
             this.insideFigure = true
             this.submitMessage = gettext('Update')
-            this.equation = this.node.attrs.equation
-            this.imgId = this.node.attrs.image
+            this.equation = this.node.content.content.find(node => node.type.name === 'figure_equation')?.attrs.equation || ''
+            this.imgId = this.node.content.content.find(node => node.type.name === 'image')?.attrs.image || false
             this.imgDb = 'document'
-            this.figureCategory = this.node.attrs.figureCategory
+            this.category = this.node.attrs.category
             this.caption = this.node.attrs.caption
             this.aligned = this.node.attrs.aligned
             this.width = this.node.attrs.width
@@ -270,20 +286,14 @@ export class FigureDialog {
             click: () => this.submitForm()
         })
 
-
         buttons.push({
             type: 'cancel'
         })
 
-
         this.dialog = new Dialog({
             id: 'figure-dialog',
             title: gettext("Enter latex math or insert an image"),
             body: configureFigureTemplate({
-                caption: this.caption,
-                aligned: this.aligned,
-                width: this.width,
-                dir: this.editor.docInfo.dir,
                 language: this.editor.view.state.doc.firstChild.attrs.language
             }),
             buttons,
@@ -297,63 +307,69 @@ export class FigureDialog {
 
         this.dialog.open()
 
-        const captionInput = this.dialog.dialogEl.querySelector('input[name=figure-caption]')
+        const alignmentSelector = dropdownSelect(
+            this.dialog.dialogEl.querySelector('.figure-alignment'),
+            {
+                onChange: newValue => {
+                    this.aligned = newValue
+                },
+                width: '80%',
+                value: this.aligned
+            }
+        )
 
-        captionInput.focus()
+        if (this.width == "100") {
+            alignmentSelector.setValue('center')
+            alignmentSelector.disable()
+            this.aligned = 'center'
+        }
 
-        this.setFigureLabel()
-        this.setFigureAlignment()
-        this.setFigureWidth()
+        dropdownSelect(
+            this.dialog.dialogEl.querySelector('.figure-width'),
+            {
+                onChange: newValue => {
+                    this.width = newValue
+                    if (this.width == "100") {
+                        alignmentSelector.setValue('center')
+                        alignmentSelector.disable()
+                        this.aligned = 'center'
+                    } else {
+                        alignmentSelector.enable()
+                    }
+                },
+                width: '80%',
+                value: this.width
+            }
+        )
 
-        if (this.imgId) {
+        dropdownSelect(
+            this.dialog.dialogEl.querySelector('.figure-category'),
+            {
+                onChange: newValue => {
+                    this.category = newValue
+                },
+                width: '80%',
+                value: this.category
+            }
+        )
+
+        dropdownSelect(
+            this.dialog.dialogEl.querySelector('.figure-caption'),
+            {
+                onChange: newValue => {
+                    this.caption = newValue === "true"
+                },
+                width: '80%',
+                value: String(this.caption)
+            }
+        )
+
+        if (this.imgId && this.imageDB.db[this.imgId]) {
             this.copyright = this.imageDB.db[this.imgId].copyright
             this.layoutImagePreview()
         } else {
             this.layoutMathEditor()
         }
 
-        addDropdownBox(
-            document.getElementById('figure-category-btn'),
-            document.getElementById('figure-category-pulldown')
-        )
-
-
-        addDropdownBox(
-            document.getElementById('figure-alignment-btn'),
-            document.getElementById('figure-alignment-pulldown')
-        )
-
-        addDropdownBox(
-            document.getElementById('figure-width-btn'),
-            document.getElementById('figure-width-pulldown')
-        )
-        document.querySelectorAll('#figure-alignment-pulldown li span').forEach(el => el.addEventListener(
-            'click',
-            event => {
-                event.preventDefault()
-                this.aligned = el.id.split('-')[2]
-                this.setFigureAlignment()
-            }
-        ))
-
-        document.querySelectorAll('#figure-width-pulldown li span').forEach(el => el.addEventListener(
-            'click',
-            event => {
-                event.preventDefault()
-                this.width = el.id.split('-')[2]
-                this.setFigureWidth()
-            }
-        ))
-
-
-        document.querySelectorAll('#figure-category-pulldown li span').forEach(el => el.addEventListener(
-            'click',
-            event => {
-                event.preventDefault()
-                this.figureCategory = el.id.split('-')[2]
-                this.setFigureLabel()
-            }
-        ))
-
     }
 }
