@@ -3,7 +3,10 @@ import {
     ensureCSS,
     WebSocketConnector,
     postJson,
-    activateWait
+    activateWait,
+    Dialog,
+    showSystemMessage,
+    addAlert
 } from "../common"
 import {
     FeedbackTab
@@ -70,11 +73,13 @@ import {
 } from './navigator'
 import {
     headerbarModel,
-    toolbarModel,
-    tableMenuModel,
     imageMenuModel,
     navigatorFilterModel,
-    selectionMenuModel
+    orderedListMenuModel,
+    selectionMenuModel,
+    tableMenuModel,
+    figureMenuModel,
+    toolbarModel
 } from "./menus"
 import {
     ModMarginboxes
@@ -100,10 +105,11 @@ import {
     tagInputPlugin,
     linksPlugin,
     marginboxesPlugin,
+    orderedListMenuPlugin,
     placeholdersPlugin,
     selectionMenuPlugin,
     settingsPlugin,
-    tableMenuPlugin,
+    tablePlugin,
     figurePlugin,
     tocRenderPlugin,
     toolbarPlugin,
@@ -113,10 +119,17 @@ import {
 import {
     buildEditorKeymap
 } from "./keymap"
+import {
+    ExportFidusFile
+} from "../exporter/native/file"
+import {
+    imageEditModel
+} from "../images/edit_dialog/model"
 
 export const COMMENT_ONLY_ROLES = ['review', 'comment']
 export const READ_ONLY_ROLES = ['read', 'read-without-comments']
 export const REVIEW_ROLES = ['review']
+export const WRITE_ROLES = ['write', 'write-tracked']
 
 export class Editor {
     // A class that contains everything that happens on the editor page.
@@ -153,11 +166,14 @@ export class Editor {
 
         this.menu = {
             headerbarModel: headerbarModel(),
-            toolbarModel: toolbarModel(),
-            tableMenuModel: tableMenuModel(),
             imageMenuModel: imageMenuModel(),
             navigatorFilterModel: navigatorFilterModel(),
-            selectionMenuModel: selectionMenuModel()
+            orderedListMenuModel: orderedListMenuModel(),
+            selectionMenuModel: selectionMenuModel(),
+            imageEditModel: imageEditModel(),
+            tableMenuModel: tableMenuModel(),
+            figureMenuModel: figureMenuModel(),
+            toolbarModel: toolbarModel()
         }
         this.client_id = Math.floor(Math.random() * 0xFFFFFFFF)
         this.clientTimeAdjustment = 0
@@ -189,10 +205,11 @@ export class Editor {
             [settingsPlugin, () => ({editor: this})],
             [documentTemplatePlugin, () => ({editor: this})],
             [trackPlugin, () => ({editor: this})],
-            [tableMenuPlugin, () => ({editor: this})],
+            [tablePlugin, () => ({editor: this})],
+            [orderedListMenuPlugin, () => ({editor: this})],
             [figurePlugin, () => ({editor: this})],
             [tocRenderPlugin, () => ({editor: this})],
-            [searchPlugin],
+            [searchPlugin]
         ]
     }
 
@@ -239,6 +256,7 @@ export class Editor {
         return Promise.all(initPromises).then(() => {
             new ModCitations(this)
             new ModFootnotes(this)
+            let resubScribed = false
             this.ws = new WebSocketConnector({
                 url: `/ws/document/${this.docInfo.id}/`,
                 appLoaded: () => this.view.state.plugins.length,
@@ -254,8 +272,12 @@ export class Editor {
                     return message
                 },
                 resubScribed: () => {
+                    if (sendableSteps(this.mod.footnotes.fnEditor.view.state)) {
+                        this.mod.collab.doc.footnoteRender = true
+                    }
+                    resubScribed = true
                     this.mod.footnotes.fnEditor.renderAllFootnotes()
-                    this.mod.collab.doc.checkVersion()
+                    this.mod.collab.doc.awaitingDiffResponse = true // wait sending diffs till the version is confirmed
                 },
                 restartMessage: () => ({type: 'get_document'}), // Too many messages have been lost and we need to restart
                 messagesElement: () => this.dom.querySelector('#unobtrusive_messages'),
@@ -271,6 +293,10 @@ export class Editor {
                         break
                     case 'connections':
                         this.mod.collab.updateParticipantList(data.participant_list)
+                        if (resubScribed) { // check version if only reconnected after being offline
+                            this.mod.collab.doc.checkVersion() // check version to sync the doc
+                            resubScribed = false
+                        }
                         break
                     case 'styles':
                         this.mod.documentTemplate.setStyles(data.styles)
@@ -304,7 +330,7 @@ export class Editor {
                             this.mod.collab.doc.checkVersion()
                             return
                         }
-                        this.mod.collab.doc.receiveFromCollaborators(data)
+                        this.mod.collab.doc.receiveDiff(data)
                         break
                     case 'confirm_diff':
                         this.mod.collab.doc.confirmDiff(data["rid"])
@@ -312,16 +338,100 @@ export class Editor {
                     case 'reject_diff':
                         this.mod.collab.doc.rejectDiff(data["rid"])
                         break
+                    case 'patch_error':
+                        showSystemMessage(gettext('Your document was out of sync and has been reset.'))
+                        break
+                    case 'access_right':
+                        if (data.access_right !== this.docInfo.access_rights) {
+                            if (sendableSteps(this.view.state) && !(WRITE_ROLES).includes(data.access_right)) {
+                                // If the user's new rights does not allow him to update document , then download a copy of the
+                                // same and ask him to re-open the document.
+                                this.handleAccessRightModification()
+                            } else {
+                                addAlert(
+                                    'info',
+                                    interpolate(
+                                        gettext('Your Access rights have been modified. You now have %(accessRight)s access to this document.'),
+                                        {accessRight: data.access_right},
+                                        true
+                                    )
+                                )
+                                this.docInfo.access_rights = data.access_right
+                            }
+                        }
+                        break
+                    default:
+                        break
+                    }
+                },
+                failedAuth: () => {
+                    if (this.view.state.plugins.length && sendableSteps(this.view.state) && this.ws.connectionCount > 0) {
+                        this.ws.online = false // To avoid Websocket trying to reconnect.
+                        new ExportFidusFile(
+                            this.getDoc({'use_current_view': true}),
+                            this.mod.db.bibDB,
+                            this.mod.db.imageDB
+                        )
+                        const sessionDialog = new Dialog({
+                            title: gettext('Session Expired'),
+                            id: "session_expiration_dialog",
+                            body: gettext('Your session expired while you were offline, so we cannot save your work to the server any longer, and it is downloaded to your computer instead. Please consider importing it into a new document.'),
+                            buttons: [{
+                                text: gettext('Proceed to Login page'),
+                                classes: 'fw-dark',
+                                click: () => {
+                                    window.location.href = '/'
+                                }
+                            }],
+                            canClose: false
+                        })
+                        sessionDialog.open()
+                    } else {
+                        window.location.href = '/'
                     }
                 }
-
             })
             this.render()
             activateWait(true)
             this.initEditor()
+
+            this.ws.ws.addEventListener('close', () => {
+                // Listen to close event and update the headerbar and toolbar view.
+                if (this.menu.toolbarViews) {
+                    this.menu.toolbarViews.forEach(view => view.update())
+                }
+                if (this.menu.headerView) {
+                    this.menu.headerView.update()
+                }
+            })
         })
     }
 
+
+    handleAccessRightModification() {
+        // This function when invoked creates a copy of document in FW format and closes editor operation.
+        new ExportFidusFile(
+            this.getDoc({'use_current_view': true}),
+            this.mod.db.bibDB,
+            this.mod.db.imageDB
+        )
+        const accessRightModifiedDialog = new Dialog({
+            title: gettext('Access rights modified'),
+            id: "access_rights_modified",
+            body: gettext('Your access rights were modified while you were offline, so we cannot save your work to the server any longer, and it is downloaded to your computer instead. Please consider importing it into a new document.'),
+            buttons: [{
+                text: gettext('Proceed to dashboard'),
+                classes: 'fw-dark',
+                click: () => {
+                    window.location.href = '/'
+                }
+            }],
+            canClose: false
+        })
+        accessRightModifiedDialog.open()
+        this.close() // Close the editor operations.
+    }
+
     close() {
         if (this.menu.toolbarViews) {
             this.menu.toolbarViews.forEach(view => view.destroy())
@@ -389,6 +499,13 @@ export class Editor {
         this.menu.toolbarViews.forEach(view => view.onResize())
     }
 
+    onBeforeUnload() {
+        if (this.app.isOffline()) {
+            showSystemMessage(gettext("Changes you made to the document since going offline will be lost, if you choose to close/refresh the tab or close the browser."))
+            return true
+        }
+    }
+
     initEditor() {
         let setFocus = false
         this.view = new EditorView(this.dom.querySelector('#document-editable'), {
@@ -439,6 +556,7 @@ export class Editor {
         this.mod.navigator.init()
         this.activateFidusPlugins()
         this.ws.init()
+
     }
 
     activateFidusPlugins() {
@@ -456,9 +574,11 @@ export class Editor {
     // Collect all components of the current doc. Needed for saving and export
     // filters
     getDoc(options = {}) {
+        const doc = (this.app.isOffline() || Boolean(options.use_current_view)) ? this.view.docView.node : this.docInfo.confirmedDoc
         const pmArticle = options.changes === 'acceptAllNoInsertions' ?
-            acceptAllNoInsertions(this.docInfo.confirmedDoc).firstChild :
-            this.docInfo.confirmedDoc.firstChild
+            acceptAllNoInsertions(doc).firstChild :
+            doc.firstChild
+
         let title = ""
         pmArticle.firstChild.forEach(
             child => {
@@ -468,7 +588,7 @@ export class Editor {
             }
         )
         return {
-            contents: pmArticle.toJSON(),
+            content: pmArticle.toJSON(),
             settings: getSettings(pmArticle),
             title: title.substring(0, 255),
             version: this.docInfo.version,
@@ -488,11 +608,11 @@ export class Editor {
             if (foundPos) {
                 return
             } else if ((node.type.groups.includes('heading') || node.type.name === 'figure') && node.attrs.id === id) {
-                foundPos = pos + 1
+                foundPos = node.type.name === 'figure' ? pos : pos + 1
                 view = this.view
             } else {
                 const anchorMark = node.marks.find(mark => mark.type.name === 'anchor')
-                if (anchorMark && anchorMark.attrs.id === id) {
+                if (anchorMark?.attrs.id === id) {
                     foundPos = pos + 1
                     view = this.view
                 }
@@ -504,11 +624,11 @@ export class Editor {
                 if (foundPos) {
                     return
                 } else if ((node.type.groups.includes('heading') || node.type.name === 'figure') && node.attrs.id === id) {
-                    foundPos = pos + 1
+                    foundPos = node.type.name === 'figure' ? pos : pos + 1
                     view = this.mod.footnotes.fnEditor.view
                 } else {
                     const anchorMark = node.marks.find(mark => mark.type.name === 'anchor')
-                    if (anchorMark && anchorMark.attrs.id === id) {
+                    if (anchorMark?.attrs.id === id) {
                         foundPos = pos + 1
                         view = this.mod.footnotes.fnEditor.view
                     }
@@ -527,7 +647,7 @@ export class Editor {
         view.dispatch(view.state.tr.setSelection(new TextSelection($pos, $pos)))
         view.focus()
         const distanceFromTop = view.coordsAtPos(pos).top - topMenuHeight
-        window.scrollBy({left: 0, top: distanceFromTop, behavior:"smooth", block:"center"})
+        window.scrollBy({left: 0, top: distanceFromTop, behavior: "smooth", block: "center"})
         return
     }
 
