@@ -2,7 +2,7 @@ import fastdom from "fastdom"
 import {DiffDOM, stringToObj} from "diff-dom"
 
 import {findTarget, cancelPromise} from "../../common"
-import {marginBoxesTemplate, marginboxFilterTemplate} from "./templates"
+import {marginBoxesTemplate, marginboxFilterTemplate, marginBoxOptions} from "./templates"
 import {getCommentDuringCreationDecoration, getSelectedChanges, getFootnoteMarkers} from "../state_plugins"
 
 /* Functions related to layouting of comments */
@@ -68,7 +68,24 @@ export class ModMarginboxes {
                 break
             case findTarget(event, '.show-marginbox-options', el):
                 this.closeAllMenus()
-                Array.from(el.target.parentElement.children).find(node => node.matches('.marginbox-options')).classList.add('fw-open')
+                if (el.target.parentElement.classList.contains('margin-box-filter-button')) {
+                    Array.from(el.target.parentElement.children).find(node => node.matches('.marginbox-options')).classList.add('fw-open')
+                } else {
+                    const user = this.editor.docInfo.owner
+                    const docInfo = this.editor.docInfo
+                    const elData = el.target.dataset
+                    const comment = {
+                        'answer': elData.hasOwnProperty('answer'),
+                        'id': elData.id,
+                        'commentId': elData.commentid,
+                        'user': Number(elData.commentuser)
+                    }
+
+                    document.body.insertAdjacentHTML('beforeend', marginBoxOptions(comment, user, docInfo))
+                    const marginboxOptions = document.body.querySelector('.comment-answer-options.marginbox-options')
+                    marginboxOptions.classList.add('fw-open')
+                    this.positionMarginBoxOptions(marginboxOptions, el.target)
+                }
                 break
             case findTarget(event, '#margin-box-filter-track', el):
                 this.filterOptions.track = !this.filterOptions.track
@@ -101,8 +118,12 @@ export class ModMarginboxes {
                 )
                 break
             }
+            case findTarget(event, '.margin-box.comment.active .show-more-less', el):
+                this.toggleShowMore(el)
+                break
             default:
                 this.closeAllMenus()
+                this.closeAllLongComments()
                 break
             }
         })
@@ -130,11 +151,20 @@ export class ModMarginboxes {
                 break
             }
         }, false)
+
+        setTimeout(this.commentOptionsOnScroll, 100)
+
     }
 
     closeAllMenus(selector = '.marginbox-options-submenu.fw-open, .marginbox-options.fw-open') {
         document.querySelectorAll(selector).forEach(
-            el => el.classList.remove('fw-open')
+            el => {
+                if (el.classList.contains('comment-answer-options')) {
+                    el.parentElement.removeChild(el)
+                } else {
+                    el.classList.remove('fw-open')
+                }
+            }
         )
     }
 
@@ -533,4 +563,50 @@ export class ModMarginboxes {
         return nodeTracks
     }
 
+    closeAllLongComments(selector = '.comment-p.show-more') {
+        document.body.querySelectorAll(selector).forEach(
+            el => {
+                el.classList.remove('show-more')
+                const showMoreButton = el.parentElement.parentElement.querySelector(".show-more-less")
+                if (showMoreButton) {
+                    showMoreButton.innerText = `${gettext("show more")}`
+                }
+            }
+        )
+    }
+
+    positionMarginBoxOptions(marginBoxDialog, showMarginboxOptionsBtn) {
+        const btnTop = showMarginboxOptionsBtn.getBoundingClientRect().top,
+            scrollTopOffset = window.pageYOffset,
+            mBoxRight = showMarginboxOptionsBtn.closest(".comment-answer-container").getBoundingClientRect().right
+
+        marginBoxDialog.style.top = `${btnTop + scrollTopOffset + 30}px`
+        marginBoxDialog.style.left = `${mBoxRight - marginBoxDialog.getBoundingClientRect().width - 10}px`
+    }
+
+    commentOptionsOnScroll() {
+        document.querySelectorAll(".comment-answer-container").forEach(
+            element => {
+                element.addEventListener("scroll", () => {
+                    const scrollTop = element.scrollTop
+                    const marginBoxOption = Array.from(element.children).find(node => node.matches(".show-marginbox-options"))
+                    if (scrollTop > 50) {
+                        marginBoxOption?.classList.add("hide")
+                    } else {
+                        marginBoxOption?.classList.remove('hide')
+                    }
+                })
+            }
+        )
+    }
+
+    toggleShowMore(element) {
+        const commentText = element.target.parentElement.parentElement.querySelector(".comment-p")
+        commentText.classList.toggle('show-more')
+        if (commentText.classList.contains('show-more')) {
+            element.target.innerText = `${gettext('show less')}`
+        } else {
+            element.target.innerText = `${gettext('show more')}`
+        }
+    }
 }
