@@ -34,7 +34,7 @@ export class DocxExporterMath {
     }
 
     setupXslt() {
-        return fetch(`${settings.STATIC_URL}xsl/mml2omml.xsl?v=${transpile.VERSION}`)
+        return fetch(`${settings_STATIC_URL}xsl/mml2omml.xsl?v=${transpile_VERSION}`)
             .then(response => response.text())
             .then(xmlString => {
                 const parser = new window.DOMParser()
@@ -43,6 +43,14 @@ export class DocxExporterMath {
             })
     }
 
+    latexToMathML(latex) {
+        return this.mathLive.convertLatexToMathMl(latex)
+            .replace(/&InvisibleTimes;/g, '&#8290;')
+            .replace(/&ApplyFunction;/g, '&#x2061;')
+            .replace(/&PlusMinus;/g, '&#177;')
+            .replace(/&times;/g, '&#215;')
+    }
+
 
     getOmml(latex) {
         if (!this.addedCambriaMath) {
@@ -50,14 +58,23 @@ export class DocxExporterMath {
             fontsEl.insertAdjacentHTML('beforeEnd', CAMBRIA_MATH_FONT_DECLARATION)
             this.addedCambriaMath = true
         }
-
         const mathml = this.domParser.parseFromString(
-            `<math xmlns="http://www.w3.org/1998/Math/MathML"><semantics>${this.mathLive.latexToMathML(latex)}</semantics></math>`,
+            `<math xmlns="http://www.w3.org/1998/Math/MathML"><semantics>${this.latexToMathML(latex)}</semantics></math>`,
             "application/xml"
         ).documentElement
-
         const omml = this.processor.transformToDocument(mathml)
-        return omml.firstChild.outerHTML
+        let ommlString = omml.firstChild.outerHTML
+        // Firefox 73 doesn't wrap the omml properly, so we remove the transformiix:result and add the m:oMath
+        if (ommlString.startsWith('<transformiix:result')) {
+            ommlString = omml.firstChild.innerHTML
+        }
+        if (!ommlString.startsWith('<m:oMath')) {
+            ommlString = this.domParser.parseFromString(
+                `<m:oMath xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math" xmlns:mml="http://www.w3.org/1998/Math/MathML">${ommlString}</m:oMath>`,
+                "application/xml"
+            ).documentElement.outerHTML
+        }
+        return ommlString
 
     }
 
