@@ -109,6 +109,13 @@ class WebSocket(BaseWebSocketHandler):
         if connection_count < 1:
             self.send_styles()
             self.send_document(False, template)
+        if connection_count >= 1:
+            # If the user is reconnecting pass along access_rights to
+            # front end to compare it with previous rights.
+            self.send_message({
+                'type': 'access_right',
+                'access_right': self.user_info.access_rights
+            })
         if self.can_communicate():
             self.handle_participant_update()
 
@@ -432,7 +439,17 @@ class WebSocket(BaseWebSocketHandler):
                             f"{json_encode(self.session['doc'].content)}"
                         )
                         self.unfixable()
-                        self.send_message({'type': 'patch_error'})
+                        patch_msg = {
+                            'type': 'patch_error',
+                            'user_id': self.user.id
+                        }
+                        self.send_message(patch_msg)
+                        # Reset collaboration to avoid any data loss issues.
+                        self.reset_collaboration(
+                            patch_msg,
+                            self.user_info.document_id,
+                            self.id
+                        )
                         return
                     # The json diff is only needed by the python backend which
                     # does not understand the steps. It can therefore be
@@ -447,7 +464,17 @@ class WebSocket(BaseWebSocketHandler):
                     self.session["node"] = updated_node
                 else:
                     self.unfixable()
-                    self.send_message({'type': 'patch_error'})
+                    patch_msg = {
+                        'type': 'patch_error',
+                        'user_id': self.user.id
+                    }
+                    self.send_message(patch_msg)
+                    # Reset collaboration to avoid any data loss issues.
+                    self.reset_collaboration(
+                        patch_msg,
+                        self.user_info.document_id,
+                        self.id
+                    )
                     return
                 self.session["doc"].content = prosemirror.to_mini_json(
                     self.session["node"].first_child
@@ -585,6 +612,17 @@ class WebSocket(BaseWebSocketHandler):
             }
             WebSocket.send_updates(message, document_id)
 
+    @classmethod
+    def reset_collaboration(cls, patch_exception_msg, document_id, sender_id):
+        logger.debug(
+            f"Action:Resetting collaboration. DocumentID:{document_id} "
+            f"Patch conflict triggered. ParticipantID:{sender_id} "
+            f"waiters:{len(cls.sessions[document_id]['participants'])}")
+        for waiter in list(cls.sessions[document_id]['participants'].values()):
+            if waiter.id != sender_id:
+                waiter.unfixable()
+                waiter.send_message(patch_exception_msg)
+
     @classmethod
     def send_updates(cls, message, document_id, sender_id=None, user_id=None):
         logger.debug(
